:	REACTEX.BAT
:
:	W.P. CARTER.  SAPRC/UCR.  DISTRIBUTION OF 2/2011  FOR SAPRC07 ONLY.
:
:	RUNS EXAMPLE OF REACTIVITY CALCULATIONS.
:	PREPARES REACTIVITY MECHANISMS THAT HAVE NOT BEEN PREPARED BEFORE.  
:
:	*NOTE*
:
:	-THE "REACT" DIRECTORY MUST BE THE DEFAULT WHEN THIS IS RUN.
:	-INSTALL.BAT MUST BE RUN FIRST TO COPY FILES
:	-F77LSRC AND SOURCE/BLDALL.BAT MUST BE RUN TO COMPILE ALL PROGRAMS.
:	-THE PGMS DIRECTORY MUST BE ON THE PATH.
:	-IF THE MECHANISMS HAVE TO BE PREPARED, THE FOLLOWING IS ALSO REQUIRED:
:	 NOTE THAT THE "NEWENV.BAT" SETS THE NEEDED ENVIRONMENT VARIABLES.
:		-THE MECHANISM FILES MUST BE IN ..\MECH\SAPRC07
:		-F77L AND G77 MUST BE INSTALLED AND ON THE PATH.
:		-THE "PGMS" ENVIRONMENT VARIABLE MUST BE SET TO THE DIRECTORY
:		 WHERE THE EXECUTALE PROGRAMS GO (THE "PGMS" DIRECTORY)
:
:	** STEP 1.  PREPARE MECHANISMS USED FOR REACTIVITY CALCS. **
:
@ECHO OFF
CD ..\MECH\SAPRC07

:	COMPILE MECHANISMS
IF NOT EXIST AIRLMPBS.EXE PRP AIRLMPBS
IF NOT EXIST AIRLMPG.EXE PRP AIRLMPG
IF NOT EXIST AIRLMPCL.EXE PRP AIRLMPCL
: IF NOT EXIST AIRLMPI.EXE PRP AIRLMPI
: IF NOT EXIST AIRLMPSP.EXE PRP AIRLMPSP
IF NOT EXIST AIRLMPMX.EXE PRP AIRLMPMX
:	COMPILE PHOTOLYSIS RATES AS FUNCTION OF ZENITH ANGLE
IF NOT EXIST STD640.FZS CALL KZSPREP
CD ..\..\REACT
:
:	MAKE SURE NECESSARY SUBFOLDERS EXIST
MD CDTFILES
MD SAPRC07
MD SAPRC07\CLCFILES
MD SAPRC07\RCTFILES
:	DO THE EXAMPLE REACTIVITY CALCULATION FOR SAPRC07
:
:	** STEP 2.  DO LUMPING ON ALL VOC'S AND MIXTURES AND CREATE DIRECTORIES **
:
IF NOT EXIST SAPRC07\TESTHC.INS CALL LUMPALL
:
:	** STEP 3.  DO BASE CASE AND EXAMPLE TEST CASE SIMULATIONS **
:		    THE EXAMPLE SCENARIO IS AVGARBBS.
:
:	THE FOLLOWING DO JUST A FEW EXAMPLE CALCULATIONS.  
:	"COMMENT OUT" THESE IF A COMPLETE SET IS DESIRED.
:	(NOTE: THE "CST2CSV 0 AVGARBBS" COMMAND IS USED TO PRODUCE AVGARBBS.CSV
:	WITH THE CONCENTRATION-TIME DATA FOR THIS SCENARIO.  THIS CAN BE DELETED
:	IF THIS CSV FILE NOT NEEDED.)
:
REACTCAL AVGARBBS
CDA2CSV AVGARBBS SAPRC07 AVGARBBS
REACTCAL AVGARBBS FORMALD
REACTCAL AVGARBBS TOLUENE
REACTCAL AVGARBBS ARBROG
:
:	Use MROPT2 to find MIR, MOIR, and EBIR points, for the "averaged
:	conditions" scenario, then calculate base case MIR, MOIR, and EBIR
:
MROPT2 AVGARBBS
REACTCAL AVGARBMR NOx-MIR AVGARBBS
REACTCAL AVGARBMO NOx-MOR AVGARBBS
REACTCAL AVGARBNL NOx-LIM AVGARBBS
:
:	Do example "averaged conditions" MIR calculation
:
REACTCAL AVGARBMR FORMALD
REACTCAL AVGARBMR TOLUENE
REACTCAL AVGARBMR ARBROG
:
:	THE FOLLOWING DOES A COMPLETE REACTIVITY SCALE CALCULATION FOR
:	AVGARBMR.  THIS INVOLVES MANY SIMULATIONS.
:
: CALL ..\MECH\SAPRC07\ALLDMS AVGARBMR
:
:	IN ANY CASE, THE RESULTS OF THE CALCULATIONS ARE SUMMARIZED IN
:	SAPRC07\CLCFILES\AVGARBBS.BAS, SAPRC07\CLCFILES\AVGARBBS.CLC, AND
:	SAPRC07\CLCFILES\AVGARBBS.CLD.  THE .CLC FILES GIVE THE INCREMENTAL 
:	AND MECHANISTIC REACTIVITIES ON A PER-MOLECULE BASIS.  (PER-CARBON 
:	FOR MIXTURES.)
:
:	** STEP 4.  COMPILE REACTIVITY RESULTS **
:
:	COMPILE REACTIVITIES
:
:	Following appropriate if not a complete reactivity scale calculation.
DMSRCT AVGARBBS NOCMP
DMSRCT AVGARBMR NOCMP
:
:	Following appropriate for a complete reactivity scale calculation.
:	(also computes reactivities of mixtures using composition [.CMP]
:	file for the mixture and the reactivities of the components)
: DMSRCT AVGARBMR
:
:	Create listing files with the names of the species and scenarios
:	used in the example calculations
@ECHO FORMALD>DOCVOC.LIS
@ECHO TOLUENE>>DOCVOC.LIS
@ECHO ARBROG>>DOCVOC.LIS
:
@ECHO AVGARBBS>DOCSCEN.LIS
@ECHO AVGARBMR>>DOCSCEN.LIS
:
:	THE FOLLOWING TABULATES JUST THE FORMALDEHYDE, TOLUENE AND BASE ROG
:	REACTIVITIES FOR AVGARBBS AND AVGARBMR.
:	 THE FIRST GIVES PER-CARBON INCREMENTAL
:	REACTIVITY, THE SECOND PER-GRAM IR, AND THE THIRD GIVES PER-CARBON
:	MECHANISTIC REACTIVITY, AND THE FOURTH GIVES PER-GRAM REACTIVITIES
:	RELATIVE TO THE BASE ROG.
:
REACTTAB F=DOCVOC.LIS F=DOCSCEN.LIS
REACTTAB F=DOCVOC.LIS F=DOCSCEN.LIS X M
REACTTAB F=DOCVOC.LIS F=DOCSCEN.LIS X MR
REACTTAB F=DOCVOC.LIS F=DOCSCEN.LIS X M ARBROG
:
:	THE FOLLOWING OUTPUTS A CSV FILE REACTEX.CSV WHICH LISTS PER-GRAM
:	REACTIVITES OF ALL DETAILED MODEL SPECIES LISTED IN THE FILE 
:	DOCVOC.LIS.  IN THIS EXAMPLE, THIS FILE CONTAINS ONLY THE THREE USED ABOVE.
:
REACTTAB F=DOCVOC.LIS F=DOCSCEN.LIS REACTEX.CSV +M
:
:	The following can be used to output a complete reactivity scale for
:	the AVGARBMR scenario into AVGARBMR.CSV if a complete calculation was done
:
: REACTTAB F=..\MECH\SAPRC07\ALLDMS.LIS AVGARBMR AVGARBMR.CSV +M
:
:	DONE.
:
:DONE
